<?xml version="1.0" encoding="utf-8"?>
<!-- Copyright (C) 2015 The Android Open Source Project

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
-->

<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp "&#160;"> ]>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <xsl:output method="html" version="1.0" encoding="UTF-8" indent="yes"/>

    <xsl:template match="/">

        <html>
            <head>
                <title>Test Report</title>
                <style type="text/css">
                    @import "compatibility-result.css";
                </style>
            </head>
            <body>
                <div>
                    <table class="title">
                        <tr>
                            <td width="40%" align="left"><img src="logo.png"></img></td>
                            <td width="60%" align="left">
                                <h1>Test Report</h1>
                            </td>
                        </tr>
                    </table>
                </div>
                <img src="newrule-green.png" align="left"></img>

                <br></br>

                <center>
                    <a href="device-info.xml" >Device Information</a>
                </center>

                <br></br>

                <div>
                    <table class="summary">
                        <tr>
                            <th colspan="2">Test Summary</th>
                        </tr>
                        <tr>
                            <td class="rowtitle">Compatibility Suite</td>
                            <td>
                                <xsl:value-of select="Result/@suite-name"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Compatibility Version</td>
                            <td>
                                <xsl:value-of select="Result/@suite-version"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Report Version</td>
                            <td>
                                <xsl:value-of select="Result/@report-version"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Host Info</td>
                            <td>
                                <xsl:value-of select="Result/@host-name"/>
                                (<xsl:value-of select="Result/@os-name"/> - <xsl:value-of select="Result/@os-version"/>)
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Plan</td>
                            <td>
                                <xsl:value-of select="Result/@plan"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Start time</td>
                            <td>
                                <xsl:value-of select="Result/@start"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">End time</td>
                            <td>
                                <xsl:value-of select="Result/@end"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Tests Passed</td>
                            <td>
                                <xsl:value-of select="Result/Summary/@pass"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Tests Failed</td>
                            <td>
                                <xsl:value-of select="Result/Summary/@failed"/>
                            </td>
                        </tr>
                        <tr>
                            <td class="rowtitle">Tests Not Executed</td>
                            <td>
                                <xsl:value-of select="Result/Summary/@not-executed"/>
                            </td>
                        </tr>
                    </table>
                </div>

                <!-- High level summary of test execution -->
                <h2 align="center">Test Summary by Module</h2>
                <div>
                    <table class="testsummary">
                        <tr>
                            <th>Module</th>
                            <th>Passed</th>
                            <th>Failed</th>
                            <th>Not Executed</th>
                            <th>Total Tests</th>
                        </tr>
                        <xsl:for-each select="Result/Module">
                            <tr>
                                <td>
                                    <xsl:variable name="href"><xsl:value-of select="@name"/> - <xsl:value-of select="@abi"/></xsl:variable>
                                    <a href="#{$href}"><xsl:value-of select="@name"/> - <xsl:value-of select="@abi"/></a>
                                </td>
                                <td>
                                    <xsl:value-of select="count(Test[@result = 'pass'])"/>
                                </td>
                                <td>
                                    <xsl:value-of select="count(Test[@result = 'fail'])"/>
                                </td>
                                <td>
                                    <xsl:value-of select="count(Test[@result = 'not-executed'])"/>
                                </td>
                                <td>
                                    <xsl:value-of select="count(Test)"/>
                                </td>
                            </tr>
                        </xsl:for-each> <!-- end Module -->
                    </table>
                </div>

                <xsl:call-template name="filteredResultTestReport">
                    <xsl:with-param name="header" select="'Failured Tests'" />
                    <xsl:with-param name="resultFilter" select="'fail'" />
                </xsl:call-template>

                <xsl:call-template name="filteredResultTestReport">
                    <xsl:with-param name="header" select="'Not Executed Tests'" />
                    <xsl:with-param name="resultFilter" select="'not-executed'" />
                </xsl:call-template>

                <h2 align="center">Detailed Test Report</h2>
                <xsl:call-template name="detailedTestReport" />

            </body>
        </html>
    </xsl:template>

    <xsl:template name="filteredResultTestReport">
        <xsl:param name="header" />
        <xsl:param name="resultFilter" />
        <xsl:variable name="numMatching" select="count(Result/Module/Test[@result=$resultFilter])" />
        <xsl:if test="$numMatching &gt; 0">
            <h2 align="center"><xsl:value-of select="$header" /> (<xsl:value-of select="$numMatching"/>)</h2>
            <xsl:call-template name="detailedTestReport">
                <xsl:with-param name="resultFilter" select="$resultFilter"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="detailedTestReport">
        <xsl:param name="resultFilter" />
        <div>
            <xsl:for-each select="Result/Module">
                <xsl:if test="$resultFilter=''
                        or count(Test[@result=$resultFilter]) &gt; 0">

                    <table class="testdetails">
                        <tr>
                            <td class="module" colspan="3">
                                <xsl:variable name="href"><xsl:value-of select="@name"/> - <xsl:value-of select="@abi"/></xsl:variable>
                                <a name="{$href}"><xsl:value-of select="@name"/> - <xsl:value-of select="@abi"/></a>
                            </td>
                        </tr>

                        <tr>
                            <th width="30%">Test</th>
                            <th width="5%">Result</th>
                            <th>Details</th>
                        </tr>

                        <!-- test -->
                        <xsl:for-each select="Test">
                            <xsl:if test="$resultFilter='' or $resultFilter=@result">
                                <tr>
                                    <td class="testname"> -- <xsl:value-of select="@name"/></td>

                                    <!-- test results -->
                                    <xsl:if test="@result='pass'">
                                        <td class="pass">
                                            <div style="text-align: center; margin-left:auto; margin-right:auto;">
                                                <xsl:value-of select="@result"/>
                                            </div>
                                        </td>
                                        <td class="failuredetails"/>
                                    </xsl:if>

                                    <xsl:if test="@result='fail'">
                                        <td class="failed">
                                            <div style="text-align: center; margin-left:auto; margin-right:auto;">
                                                <xsl:value-of select="@result"/>
                                            </div>
                                        </td>
                                        <td class="failuredetails">
                                            <div class="details">
                                                <xsl:value-of select="Failure/@message"/>
                                            </div>
                                        </td>
                                    </xsl:if>

                                    <xsl:if test="@result='not-executed'">
                                        <td class="not-executed">
                                            <div style="text-align: center; margin-left:auto; margin-right:auto;">
                                                <xsl:value-of select="@result"/>
                                            </div>
                                        </td>
                                        <td class="failuredetails"></td>
                                    </xsl:if>
                                </tr> <!-- finished with a row -->
                            </xsl:if>
                        </xsl:for-each> <!-- end test -->
                    </table>
                </xsl:if>
            </xsl:for-each> <!-- end test Module -->
        </div>
    </xsl:template>

    <!-- Take a delimited string and insert line breaks after a some number of elements. -->
    <xsl:template name="formatDelimitedString">
        <xsl:param name="string" />
        <xsl:param name="numTokensPerRow" select="10" />
        <xsl:param name="tokenIndex" select="1" />
        <xsl:if test="$string">
            <!-- Requires the last element to also have a delimiter after it. -->
            <xsl:variable name="token" select="substring-before($string, ';')" />
            <xsl:value-of select="$token" />
            <xsl:text>&#160;</xsl:text>

            <xsl:if test="$tokenIndex mod $numTokensPerRow = 0">
                <br />
            </xsl:if>

            <xsl:call-template name="formatDelimitedString">
                <xsl:with-param name="string" select="substring-after($string, ';')" />
                <xsl:with-param name="numTokensPerRow" select="$numTokensPerRow" />
                <xsl:with-param name="tokenIndex" select="$tokenIndex + 1" />
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>
